pub enum SessionError {
Steam,
BackendClosed,
InvalidConnection,
ProblemDetectedLocally,
Ended(NetConnectionEnd),
}Available on non-
target_family=wasm only.Expand description
Error that occurs when polling a session using the SteamNetIo IO layer.
Variants
Steam
Internal Steamworks SDK error occurred.
BackendClosed
Backend task was unexpectedly cancelled.
InvalidConnection
Connection is no longer valid under the Steamworks API.
ProblemDetectedLocally
Problem has been detected locally, i.e. a timeout, network connection lost, etc.
Ended(NetConnectionEnd)
Connection ended.